# TofuPilot Python client

[![PyPI version](https://badge.fury.io/py/tofupilot.svg)](https://badge.fury.io/py/tofupilot)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

The official open-source Python client for [TofuPilot](https://tofupilot.com). Quickly and seamlessly integrate all your hardware test runs into one app with just a few lines of Python.

## Table of Contents

- [Installation](#installation)
- [Usage](#usage)
- [Contributing](#contributing)
- [License](#license)
- [Contact](#contact)

## Installation

Package can be installed via pip

```bash
pip install tofupilot
```

## Usage

### Documentation

You can find the full TofuPilot documentation [here](https://tofupilot.com/docs).

### Examples

For usage examples, see the [examples](https://github.com/tofupilot/examples/tree/main/docs/client).

## Contributing

Please read [CONTRIBUTING](https://github.com/tofupilot/python-client/blob/main/CONTRIBUTING.md) for details on our code of conduct, and the process for submitting pull requests.

## License

This project is licensed under the MIT License - see the [LICENSE](https://github.com/tofupilot/python-client/blob/main/LICENSE) for details.

## Contact

If you have any questions or feedback, feel free to open an issue or contact us at support@tofupilot.com.
